/**
 * Introduction
 *
 * @title ROV - Easy applications from C
 *
 * @copyright Jason Tribbeck / 7th ARM 1994-2001
 *
 * @authors Jason Tribbeck
 *
 * @file preference.h
 *
 * @type helper
 *
 * @description
 *
 * The preference helper is designed to create a common preference
 * scheme, with tabbed preference panes, and standard button features.
 *
 * See the preferences tutorial for more details.
 */

#ifndef __rov_preference
#define __rov_preference


#ifdef __cplusplus
extern "C"
{
#endif

/**
 * Definition of a preference event handler.
 * @param event the event code.
 * @param page the page the event occurred on.
 * @see PREFERENCE_NEW
 * @see PREFERENCE_CLOSE
 * @see PREFERENCE_CHANGE
 * @see PREFERENCE_SAVE
 * @see PREFERENCE_CANCEL
 * @see PREFERENCE_SET
 * @see PREFERENCE_SETANDCLOSE
 */
typedef void (*_rov_prefh)(int event,
			   int page); 			/* Operation, Page number 	 	 */

/**
 * Initialises the preference helper.
 * @param pages the number of pages in the preferece system.
 * @param title the title of the preference canvas.
 * @param handler the preference event handler.
 * @return the canvas for the preference system.
 * @note You can only have one preference system per application.
 * @see _rov_prefh
 */
canvas preference_init(int pages,
		       char *title,
		       _rov_prefh handler);

/**
 * Create a preference pane for a new page.
 * @param title the preference title.
 * @param handler the preference handler for this page. You can use
 * the parent event handler if you do not wish to write several
 * preference event handlers.
 * @return the canvas created for the page.
 * @see preference_makecanvaspage()
 */
canvas preference_makepage(char *title,
			   _rov_prefh handler);

/**
 * Create a preference pane from an existing canvas.
 * @param title the preference title.
 * @param handler the preference handler for this page.
 * @param c the canvas to use.
 * @return the canvas passed in.
 * @see preference_makepage()
 */
canvas preference_makecanvaspage(char *title,
				 _rov_prefh handler,
				 canvas c);

/**
 * Open the preferences at a set page,
 * @param page the page to open at.
 */
void preference_open(int page);

/**
 * Close the preferences.
 */
void preference_close(void);

/**
 * Event code called when prefereces are opened for the first time.
 */
#define PREFERENCE_NEW		(0)

/**
 * Called when the preferences page has changed to the new page.
 */
#define PREFERENCE_CHANGE	(1)

/**
 * Called when the preferences page has been closed.
 */
#define PREFERENCE_CLOSE	(2)

/**
 * Called when the 'default' button is pressed.
 */
#define PREFERENCE_DEFAULT	(3)

/**
 * Called when the 'save' button is pressed.
 */
#define PREFERENCE_SAVE		(4)

/**
 * Called when the 'cancel' button is pressed.
 */
#define PREFERENCE_CANCEL	(5)

/**
 * Called when the 'set' button is pressed with ADJUST.
 */
#define PREFERENCE_SET		(6)

/**
 * Called when the 'set' button is pressed with SELECT.
 */
#define PREFERENCE_SETANDCLOSE	(7)

/**
 * @section Preference canvas sizes
 */
#define PREFERENCE_MAXX (740)
#define PREFERENCE_MAXY (512)

/**
 * Definition of a null page
 */
#define PREFERENCE_NULLPAGE (-1)


#ifdef __cplusplus
}
#endif

#endif
